# -*- coding: utf-8 -*-
# mdx-journal (c) 2014-2016 Ian Dennis Miller

__version__ = '0.1.4'
__author__ = 'Ian Dennis Miller'
__email__ = 'iandennismiller@gmail.com'
__url__ = 'https://github.com/iandennismiller/mdx_journal'
__copyright__ = '2013-2016, Ian Dennis Miller'



# mdx_journal (c) Ian Dennis Miller

from setuptools import setup
import os
import re


# from https://github.com/flask-admin/flask-admin/blob/master/setup.py
def fpath(name):
    return os.path.join(os.path.dirname(__file__), name)


def read(fname):
    return open(fpath(fname)).read()


file_text = read(fpath('mdx_journal/__meta__.py'))


def grep(attrname):
    pattern = r"{0}\W*=\W*'([^']+)'".format(attrname)
    strval, = re.findall(pattern, file_text)
    return strval


setup(
    name='mdx_journal',
    description='Python-Markdown extension for annotating gthnk journal text files',
    long_description=read('Readme.rst'),
    version=grep('__version__'),
    author=grep('__author__'),
    author_email=grep('__email__'),
    url=grep('__url__'),
    packages=[
        'mdx_journal',
    ],
    install_requires=read('requirements.txt'),
    zip_safe=False,
    license='MIT',
    include_package_data=True,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: BSD License',
        'Intended Audience :: Developers',
        'Environment :: Web Environment',
        'Programming Language :: Python',
        'Topic :: Text Processing :: Filters',
        'Topic :: Text Processing :: Markup :: HTML',
    ]
)



import re
from markdown.preprocessors import Preprocessor
from markdown import Extension

__version__ = "0.1.1"


class JournalPreprocessor(Preprocessor):
    pattern_time = re.compile(r'^(\d{4})$')
    pattern_date = re.compile(r'^(\d{4}-\d{2}-\d{2})$')

    def run(self, lines):
        return [self._t1(self._t2(line)) for line in lines]

    def _t1(self, line):
        return self.pattern_time.sub(self._replacer_time, line)

    def _t2(self, line):
        return self.pattern_date.sub(self._replacer_date, line)

    def _replacer_time(self, match):
        time_str = match.groups()
        return '<h4>%s</h4>' % (time_str)

    def _replacer_date(self, match):
        time_str = match.groups()
        return '<h3>%s</h3>' % (time_str)


class JournalExtension(Extension):
    def extendMarkdown(self, md, md_globals):
        md.preprocessors.add('journal', JournalPreprocessor(md), '<reference')


def makeExtension(configs=None):
    return JournalExtension(configs=configs)
